You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by dp...@apache.org on 2021/10/01 07:22:48 UTC

[cordova-ios] branch master updated: refactor: update allow list name (#1032)

This is an automated email from the ASF dual-hosted git repository.

dpogue pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/cordova-ios.git


The following commit(s) were added to refs/heads/master by this push:
     new 2198319  refactor: update allow list name (#1032)
2198319 is described below

commit 21983197042908dff4cd49b00728b0c1d6703322
Author: エリス <er...@users.noreply.github.com>
AuthorDate: Fri Oct 1 16:22:42 2021 +0900

    refactor: update allow list name (#1032)
    
    * refactor: update allow list naming
    
    * chore: improve variable nameing
    
    * chore: update doc url to cordova main docs
---
 Cordova.podspec                                    |   2 +-
 .../CDVIntentAndNavigationFilter.h                 |   4 +-
 .../CDVIntentAndNavigationFilter.m                 |  24 +--
 CordovaLib/Classes/Public/CDV.h                    |   2 +-
 .../Public/{CDVWhitelist.h => CDVAllowList.h}      |   6 +-
 .../Public/{CDVWhitelist.m => CDVAllowList.m}      |  54 +++---
 CordovaLib/Classes/Public/CDVCommandDelegate.h     |   2 +-
 CordovaLib/Classes/Public/CDVViewController.m      |   4 +-
 CordovaLib/Cordova/Cordova.h                       |   2 +-
 CordovaLib/CordovaLib.xcodeproj/project.pbxproj    |  24 +--
 bin/templates/project/__PROJECT_NAME__/config.xml  |   2 +-
 bin/templates/project/www/index.html               |   2 +-
 bin/templates/scripts/cordova/lib/prepare.js       |   4 +-
 .../{CDVWhitelistTests.m => CDVAllowListTests.m}   | 186 ++++++++++-----------
 tests/CordovaLibTests/CDVWebViewDelegateTests.m    |   2 +-
 .../CordovaLibTests.xcodeproj/project.pbxproj      |  12 +-
 tests/spec/unit/fixtures/dummyProj/config.xml      |   1 -
 .../CordovaLib.xcodeproj/project.pbxproj           |  24 +--
 18 files changed, 178 insertions(+), 179 deletions(-)

diff --git a/Cordova.podspec b/Cordova.podspec
index df775af..dec80f1 100644
--- a/Cordova.podspec
+++ b/Cordova.podspec
@@ -39,7 +39,7 @@ Pod::Spec.new do |s|
   s.default_subspec  = 'Cordova'
   s.subspec 'Cordova' do |cordova|
       cordova.source_files = 'CordovaLib/Classes/**/*.{h,m}', 'CordovaLib/Cordova/Cordova.h'
-      cordova.public_header_files = 'CordovaLib/Classes/Public/CDV.h', 'CordovaLib/Classes/Public/CDVAppDelegate.h', 'CordovaLib/Classes/Public/CDVAvailability.h', 'CordovaLib/Classes/Public/CDVAvailabilityDeprecated.h', 'CordovaLib/Classes/Public/CDVCommandDelegate.h', 'CordovaLib/Classes/Public/CDVCommandDelegateImpl.h', 'CordovaLib/Classes/Public/CDVCommandQueue.h', 'CordovaLib/Classes/Public/CDVConfigParser.h', 'CordovaLib/Classes/Public/CDVInvokedUrlCommand.h', 'CordovaLib/Classes/P [...]
+      cordova.public_header_files = 'CordovaLib/Classes/Public/CDV.h', 'CordovaLib/Classes/Public/CDVAllowList.h', 'CordovaLib/Classes/Public/CDVAppDelegate.h', 'CordovaLib/Classes/Public/CDVAvailability.h', 'CordovaLib/Classes/Public/CDVAvailabilityDeprecated.h', 'CordovaLib/Classes/Public/CDVCommandDelegate.h', 'CordovaLib/Classes/Public/CDVCommandDelegateImpl.h', 'CordovaLib/Classes/Public/CDVCommandQueue.h', 'CordovaLib/Classes/Public/CDVConfigParser.h', 'CordovaLib/Classes/Public/CD [...]
       cordova.prefix_header_contents = ''
       cordova.requires_arc = true
   end
diff --git a/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.h b/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.h
index 14c6a66..652cb39 100644
--- a/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.h
+++ b/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.h
@@ -18,7 +18,7 @@
  */
 
 #import <Cordova/CDVPlugin.h>
-#import <Cordova/CDVWhitelist.h>
+#import <Cordova/CDVAllowList.h>
 
 #define CDVWebViewNavigationType int
 
@@ -30,7 +30,7 @@ typedef NS_ENUM(NSInteger, CDVIntentAndNavigationFilterValue) {
 
 @interface CDVIntentAndNavigationFilter : CDVPlugin <NSXMLParserDelegate>
 
-+ (CDVIntentAndNavigationFilterValue) filterUrl:(NSURL*)url intentsWhitelist:(CDVWhitelist*)intentsWhitelist navigationsWhitelist:(CDVWhitelist*)navigationsWhitelist;
++ (CDVIntentAndNavigationFilterValue) filterUrl:(NSURL*)url allowIntentsList:(CDVAllowList*)allowIntentsList navigationsAllowList:(CDVAllowList*)navigationsAllowList;
 + (BOOL)shouldOverrideLoadWithRequest:(NSURLRequest*)request navigationType:(CDVWebViewNavigationType)navigationType filterValue:(CDVIntentAndNavigationFilterValue)filterValue;
 + (BOOL)shouldOpenURLRequest:(NSURLRequest*)request navigationType:(CDVWebViewNavigationType)navigationType;
 @end
diff --git a/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.m b/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.m
index 3021f8f..4430426 100644
--- a/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.m
+++ b/CordovaLib/Classes/Private/Plugins/CDVIntentAndNavigationFilter/CDVIntentAndNavigationFilter.m
@@ -24,8 +24,8 @@
 
 @property (nonatomic, readwrite) NSMutableArray* allowIntents;
 @property (nonatomic, readwrite) NSMutableArray* allowNavigations;
-@property (nonatomic, readwrite) CDVWhitelist* allowIntentsWhitelist;
-@property (nonatomic, readwrite) CDVWhitelist* allowNavigationsWhitelist;
+@property (nonatomic, readwrite) CDVAllowList* allowIntentsList;
+@property (nonatomic, readwrite) CDVAllowList* allowNavigationsList;
 
 @end
 
@@ -61,8 +61,8 @@
 
 - (void)parserDidEndDocument:(NSXMLParser*)parser
 {
-    self.allowIntentsWhitelist = [[CDVWhitelist alloc] initWithArray:self.allowIntents];
-    self.allowNavigationsWhitelist = [[CDVWhitelist alloc] initWithArray:self.allowNavigations];
+    self.allowIntentsList = [[CDVAllowList alloc] initWithArray:self.allowIntents];
+    self.allowNavigationsList = [[CDVAllowList alloc] initWithArray:self.allowNavigations];
 }
 
 - (void)parser:(NSXMLParser*)parser parseErrorOccurred:(NSError*)parseError
@@ -79,13 +79,13 @@
     }
 }
 
-+ (CDVIntentAndNavigationFilterValue) filterUrl:(NSURL*)url intentsWhitelist:(CDVWhitelist*)intentsWhitelist navigationsWhitelist:(CDVWhitelist*)navigationsWhitelist
++ (CDVIntentAndNavigationFilterValue) filterUrl:(NSURL*)url allowIntentsList:(CDVAllowList*)allowIntentsList navigationsAllowList:(CDVAllowList*)navigationsAllowList
 {
     // a URL can only allow-intent OR allow-navigation, if both are specified,
     // only allow-navigation is allowed
 
-    BOOL allowNavigationsPass = [navigationsWhitelist URLIsAllowed:url logFailure:NO];
-    BOOL allowIntentPass = [intentsWhitelist URLIsAllowed:url logFailure:NO];
+    BOOL allowNavigationsPass = [navigationsAllowList URLIsAllowed:url logFailure:NO];
+    BOOL allowIntentPass = [allowIntentsList URLIsAllowed:url logFailure:NO];
 
     if (allowNavigationsPass && allowIntentPass) {
         return CDVIntentAndNavigationFilterValueNavigationAllowed;
@@ -100,7 +100,7 @@
 
 - (CDVIntentAndNavigationFilterValue) filterUrl:(NSURL*)url
 {
-    return [[self class] filterUrl:url intentsWhitelist:self.allowIntentsWhitelist navigationsWhitelist:self.allowNavigationsWhitelist];
+    return [[self class] filterUrl:url allowIntentsList:self.allowIntentsList navigationsAllowList:self.allowNavigationsList];
 }
 
 #define CDVWebViewNavigationTypeLinkClicked 0
@@ -118,8 +118,8 @@
 
 + (BOOL)shouldOverrideLoadWithRequest:(NSURLRequest*)request navigationType:(CDVWebViewNavigationType)navigationType filterValue:(CDVIntentAndNavigationFilterValue)filterValue
 {
-    NSString* allowIntents_whitelistRejectionFormatString = @"ERROR External navigation rejected - <allow-intent> not set for url='%@'";
-    NSString* allowNavigations_whitelistRejectionFormatString = @"ERROR Internal navigation rejected - <allow-navigation> not set for url='%@'";
+    NSString* allowIntents_allowListRejectionFormatString = @"ERROR External navigation rejected - <allow-intent> not set for url='%@'";
+    NSString* allowNavigations_allowListRejectionFormatString = @"ERROR Internal navigation rejected - <allow-navigation> not set for url='%@'";
 
     NSURL* url = [request URL];
 
@@ -136,10 +136,10 @@
             return NO;
         case CDVIntentAndNavigationFilterValueNoneAllowed:
             // allow-navigation attempt failed for sure
-            NSLog(@"%@", [NSString stringWithFormat:allowNavigations_whitelistRejectionFormatString, [url absoluteString]]);
+            NSLog(@"%@", [NSString stringWithFormat:allowNavigations_allowListRejectionFormatString, [url absoluteString]]);
             // anchor tag link means it was an allow-intent attempt that failed as well
             if (CDVWebViewNavigationTypeLinkClicked == navigationType) {
-                NSLog(@"%@", [NSString stringWithFormat:allowIntents_whitelistRejectionFormatString, [url absoluteString]]);
+                NSLog(@"%@", [NSString stringWithFormat:allowIntents_allowListRejectionFormatString, [url absoluteString]]);
             }
             return NO;
     }
diff --git a/CordovaLib/Classes/Public/CDV.h b/CordovaLib/Classes/Public/CDV.h
index 8706ef4..2ae36f8 100644
--- a/CordovaLib/Classes/Public/CDV.h
+++ b/CordovaLib/Classes/Public/CDV.h
@@ -25,6 +25,6 @@
 #import "CDVViewController.h"
 #import "CDVCommandDelegate.h"
 #import "CDVInvokedUrlCommand.h"
-#import "CDVWhitelist.h"
+#import "CDVAllowList.h"
 #import "CDVScreenOrientationDelegate.h"
 #import "CDVTimer.h"
diff --git a/CordovaLib/Classes/Public/CDVWhitelist.h b/CordovaLib/Classes/Public/CDVAllowList.h
similarity index 86%
rename from CordovaLib/Classes/Public/CDVWhitelist.h
rename to CordovaLib/Classes/Public/CDVAllowList.h
index 9165097..57814b1 100644
--- a/CordovaLib/Classes/Public/CDVWhitelist.h
+++ b/CordovaLib/Classes/Public/CDVAllowList.h
@@ -19,11 +19,11 @@
 
 #import <Foundation/Foundation.h>
 
-extern NSString* const kCDVDefaultWhitelistRejectionString;
+extern NSString* const kCDVDefaultAllowListRejectionString;
 
-@interface CDVWhitelist : NSObject
+@interface CDVAllowList : NSObject
 
-@property (nonatomic, copy) NSString* whitelistRejectionFormatString;
+@property (nonatomic, copy) NSString* allowListRejectionFormatString;
 
 - (id)initWithArray:(NSArray*)array;
 - (BOOL)schemeIsAllowed:(NSString*)scheme;
diff --git a/CordovaLib/Classes/Public/CDVCommandDelegate.h b/CordovaLib/Classes/Public/CDVCommandDelegate.h
index ac82727..3d15d9a 100644
--- a/CordovaLib/Classes/Public/CDVCommandDelegate.h
+++ b/CordovaLib/Classes/Public/CDVCommandDelegate.h
@@ -22,7 +22,7 @@
 
 @class CDVPlugin;
 @class CDVPluginResult;
-@class CDVWhitelist;
+@class CDVAllowList;
 
 typedef NSURL* (^ UrlTransformerBlock)(NSURL*);
 
diff --git a/CordovaLib/Classes/Public/CDVViewController.m b/CordovaLib/Classes/Public/CDVViewController.m
index dcec958..50dcf5e 100644
--- a/CordovaLib/Classes/Public/CDVViewController.m
+++ b/CordovaLib/Classes/Public/CDVViewController.m
@@ -180,7 +180,7 @@
 
     [self parseSettingsWithParser:delegate];
 
-    // Get the plugin dictionary, whitelist and settings from the delegate.
+    // Get the plugin dictionary, allowList and settings from the delegate.
     self.pluginsMap = delegate.pluginsDict;
     self.startupPluginNames = delegate.startupPluginNames;
     self.settings = delegate.settings;
@@ -611,7 +611,7 @@
 - (id)getCommandInstance:(NSString*)pluginName
 {
     // first, we try to find the pluginName in the pluginsMap
-    // (acts as a whitelist as well) if it does not exist, we return nil
+    // (acts as a allowList as well) if it does not exist, we return nil
     // NOTE: plugin names are matched as lowercase to avoid problems - however, a
     // possible issue is there can be duplicates possible if you had:
     // "org.apache.cordova.Foo" and "org.apache.cordova.foo" - only the lower-cased entry will match
diff --git a/CordovaLib/Cordova/Cordova.h b/CordovaLib/Cordova/Cordova.h
index 62675ac..75b265e 100644
--- a/CordovaLib/Cordova/Cordova.h
+++ b/CordovaLib/Cordova/Cordova.h
@@ -44,6 +44,6 @@ FOUNDATION_EXPORT const unsigned char CordovaVersionString[];
 #import <Cordova/NSDictionary+CordovaPreferences.h>
 #import <Cordova/NSMutableArray+QueueAdditions.h>
 #import <Cordova/CDVWebViewUIDelegate.h>
-#import <Cordova/CDVWhitelist.h>
+#import <Cordova/CDVAllowList.h>
 #import <Cordova/CDVScreenOrientationDelegate.h>
 #import <Cordova/CDVTimer.h>
diff --git a/CordovaLib/CordovaLib.xcodeproj/project.pbxproj b/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
index f0958e4..c0205fd 100644
--- a/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
+++ b/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
@@ -62,8 +62,8 @@
 		7ED95D501AB9029B008C4574 /* CDVViewController.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2A1AB9029B008C4574 /* CDVViewController.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		7ED95D511AB9029B008C4574 /* CDVViewController.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2B1AB9029B008C4574 /* CDVViewController.m */; };
 		7ED95D521AB9029B008C4574 /* CDVWebViewEngineProtocol.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		7ED95D531AB9029B008C4574 /* CDVWhitelist.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		7ED95D541AB9029B008C4574 /* CDVWhitelist.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */; };
+		7ED95D531AB9029B008C4574 /* CDVAllowList.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		7ED95D541AB9029B008C4574 /* CDVAllowList.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */; };
 		7ED95D571AB9029B008C4574 /* NSDictionary+CordovaPreferences.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		7ED95D581AB9029B008C4574 /* NSDictionary+CordovaPreferences.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */; };
 		7ED95D591AB9029B008C4574 /* NSMutableArray+QueueAdditions.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */; settings = {ATTRIBUTES = (Public, ); }; };
@@ -78,7 +78,7 @@
 		9052DE782150D040008E83D4 /* CDVPluginResult.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D221AB9029B008C4574 /* CDVPluginResult.m */; };
 		9052DE792150D040008E83D4 /* CDVTimer.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D251AB9029B008C4574 /* CDVTimer.m */; };
 		9052DE7C2150D040008E83D4 /* CDVViewController.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2B1AB9029B008C4574 /* CDVViewController.m */; };
-		9052DE7D2150D040008E83D4 /* CDVWhitelist.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */; };
+		9052DE7D2150D040008E83D4 /* CDVAllowList.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */; };
 		9052DE7E2150D040008E83D4 /* NSDictionary+CordovaPreferences.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */; };
 		9052DE7F2150D040008E83D4 /* NSMutableArray+QueueAdditions.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D341AB9029B008C4574 /* NSMutableArray+QueueAdditions.m */; };
 		9052DE802150D040008E83D4 /* CDVJSON_private.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95CF41AB9028C008C4574 /* CDVJSON_private.m */; };
@@ -112,7 +112,7 @@
 		C0C01EC81E39131A0056E6CB /* CDVTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D241AB9029B008C4574 /* CDVTimer.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECB1E39131A0056E6CB /* CDVViewController.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2A1AB9029B008C4574 /* CDVViewController.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECC1E39131A0056E6CB /* CDVWebViewEngineProtocol.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		C0C01ECD1E39131A0056E6CB /* CDVWhitelist.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		C0C01ECD1E39131A0056E6CB /* CDVAllowList.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECE1E39131A0056E6CB /* NSDictionary+CordovaPreferences.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECF1E39131A0056E6CB /* NSMutableArray+QueueAdditions.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */; settings = {ATTRIBUTES = (Public, ); }; };
 /* End PBXBuildFile section */
@@ -165,8 +165,8 @@
 		7ED95D2A1AB9029B008C4574 /* CDVViewController.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVViewController.h; sourceTree = "<group>"; };
 		7ED95D2B1AB9029B008C4574 /* CDVViewController.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVViewController.m; sourceTree = "<group>"; };
 		7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVWebViewEngineProtocol.h; sourceTree = "<group>"; };
-		7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVWhitelist.h; sourceTree = "<group>"; };
-		7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVWhitelist.m; sourceTree = "<group>"; };
+		7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVAllowList.h; sourceTree = "<group>"; };
+		7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVAllowList.m; sourceTree = "<group>"; };
 		7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = "NSDictionary+CordovaPreferences.h"; sourceTree = "<group>"; };
 		7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = "NSDictionary+CordovaPreferences.m"; sourceTree = "<group>"; };
 		7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = "NSMutableArray+QueueAdditions.h"; sourceTree = "<group>"; };
@@ -321,8 +321,8 @@
 				4E23F8F523E16E96006CD852 /* CDVWebViewProcessPoolFactory.m */,
 				7ED95D2B1AB9029B008C4574 /* CDVViewController.m */,
 				7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */,
-				7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */,
-				7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */,
+				7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */,
+				7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */,
 				7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */,
 				7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */,
 				7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */,
@@ -378,7 +378,7 @@
 				C0C01EC81E39131A0056E6CB /* CDVTimer.h in Headers */,
 				C0C01ECB1E39131A0056E6CB /* CDVViewController.h in Headers */,
 				C0C01ECC1E39131A0056E6CB /* CDVWebViewEngineProtocol.h in Headers */,
-				C0C01ECD1E39131A0056E6CB /* CDVWhitelist.h in Headers */,
+				C0C01ECD1E39131A0056E6CB /* CDVAllowList.h in Headers */,
 				C0C01ECE1E39131A0056E6CB /* NSDictionary+CordovaPreferences.h in Headers */,
 				4E23F90323E17FFA006CD852 /* CDVWebViewUIDelegate.h in Headers */,
 				C0C01ECF1E39131A0056E6CB /* NSMutableArray+QueueAdditions.h in Headers */,
@@ -417,7 +417,7 @@
 				7ED95D501AB9029B008C4574 /* CDVViewController.h in Headers */,
 				7ED95D521AB9029B008C4574 /* CDVWebViewEngineProtocol.h in Headers */,
 				4E23F90023E16E96006CD852 /* CDVWebViewEngine.h in Headers */,
-				7ED95D531AB9029B008C4574 /* CDVWhitelist.h in Headers */,
+				7ED95D531AB9029B008C4574 /* CDVAllowList.h in Headers */,
 				7ED95D571AB9029B008C4574 /* NSDictionary+CordovaPreferences.h in Headers */,
 				7ED95D591AB9029B008C4574 /* NSMutableArray+QueueAdditions.h in Headers */,
 				7ED95D021AB9028C008C4574 /* CDVDebug.h in Headers */,
@@ -545,7 +545,7 @@
 				4F56D82D254A2EB50063F1D6 /* CDVWebViewEngine.m in Sources */,
 				9052DE7C2150D040008E83D4 /* CDVViewController.m in Sources */,
 				4F56D83C254A2F2F0063F1D6 /* CDVURLSchemeHandler.m in Sources */,
-				9052DE7D2150D040008E83D4 /* CDVWhitelist.m in Sources */,
+				9052DE7D2150D040008E83D4 /* CDVAllowList.m in Sources */,
 				9052DE7E2150D040008E83D4 /* NSDictionary+CordovaPreferences.m in Sources */,
 				9052DE7F2150D040008E83D4 /* NSMutableArray+QueueAdditions.m in Sources */,
 				9052DE802150D040008E83D4 /* CDVJSON_private.m in Sources */,
@@ -574,7 +574,7 @@
 				4E23F8FE23E16E96006CD852 /* CDVWebViewEngine.m in Sources */,
 				4E23F8FB23E16E96006CD852 /* CDVWebViewProcessPoolFactory.m in Sources */,
 				7ED95D511AB9029B008C4574 /* CDVViewController.m in Sources */,
-				7ED95D541AB9029B008C4574 /* CDVWhitelist.m in Sources */,
+				7ED95D541AB9029B008C4574 /* CDVAllowList.m in Sources */,
 				7ED95D581AB9029B008C4574 /* NSDictionary+CordovaPreferences.m in Sources */,
 				7ED95D5A1AB9029B008C4574 /* NSMutableArray+QueueAdditions.m in Sources */,
 				7ED95D041AB9028C008C4574 /* CDVJSON_private.m in Sources */,
diff --git a/bin/templates/project/__PROJECT_NAME__/config.xml b/bin/templates/project/__PROJECT_NAME__/config.xml
index e6e049c..4727ba1 100644
--- a/bin/templates/project/__PROJECT_NAME__/config.xml
+++ b/bin/templates/project/__PROJECT_NAME__/config.xml
@@ -32,7 +32,7 @@
 
     <content src="index.html" />
 
-    <!-- Whitelist docs: https://github.com/apache/cordova-plugin-whitelist -->
+    <!-- AllowList docs: https://cordova.apache.org/docs/en/latest/ -->
     <access origin="*" />
     <!-- Grant certain URLs the ability to launch external applications. This
          behaviour is set to match that of Cordova versions before 3.6.0, and
diff --git a/bin/templates/project/www/index.html b/bin/templates/project/www/index.html
index 65aaede..dad58da 100755
--- a/bin/templates/project/www/index.html
+++ b/bin/templates/project/www/index.html
@@ -21,7 +21,7 @@
     <head>
         <!--
         Customize this policy to fit your own app's needs. For more guidance, see:
-            https://github.com/apache/cordova-plugin-whitelist/blob/master/README.md#content-security-policy
+            https://cordova.apache.org/docs/en/latest/
         Some notes:
             * gap: is required only on iOS (when using WkWebView) and is needed for JS->native communication
             * https://ssl.gstatic.com is required only on Android and is needed for TalkBack to function properly
diff --git a/bin/templates/scripts/cordova/lib/prepare.js b/bin/templates/scripts/cordova/lib/prepare.js
index 7badf9f..ac6ef88 100644
--- a/bin/templates/scripts/cordova/lib/prepare.js
+++ b/bin/templates/scripts/cordova/lib/prepare.js
@@ -957,7 +957,7 @@ function processAccessAndAllowNavigationEntries (config) {
                 allows_arbitrary_loads_in_web_content: currentElement.allows_arbitrary_loads_in_web_content,
                 allows_local_networking: currentElement.allows_local_networking
             };
-            const obj = parseWhitelistUrlForATS(currentElement.href, options);
+            const obj = parseAllowlistUrlForATS(currentElement.href, options);
 
             if (obj) {
                 // we 'union' duplicate entries
@@ -996,7 +996,7 @@ function processAccessAndAllowNavigationEntries (config) {
 
     null is returned if the URL cannot be parsed, or is to be skipped for ATS.
 */
-function parseWhitelistUrlForATS (url, options) {
+function parseAllowlistUrlForATS (url, options) {
     // @todo 'url.parse' was deprecated since v11.0.0. Use 'url.URL' constructor instead.
     const href = URL.parse(url); // eslint-disable-line
     const retObj = {};
diff --git a/tests/CordovaLibTests/CDVWhitelistTests.m b/tests/CordovaLibTests/CDVAllowListTests.m
similarity index 52%
rename from tests/CordovaLibTests/CDVWhitelistTests.m
rename to tests/CordovaLibTests/CDVAllowListTests.m
index 15f5dbf..8a6f0f1 100644
--- a/tests/CordovaLibTests/CDVWhitelistTests.m
+++ b/tests/CordovaLibTests/CDVAllowListTests.m
@@ -19,13 +19,13 @@
 
 #import <XCTest/XCTest.h>
 
-#import <Cordova/CDVWhitelist.h>
+#import <Cordova/CDVAllowList.h>
 #import "CDVIntentAndNavigationFilter.h"
 
-@interface CDVWhitelistTests : XCTestCase
+@interface CDVAllowListTests : XCTestCase
 @end
 
-@implementation CDVWhitelistTests
+@implementation CDVAllowListTests
 
 - (void)setUp
 {
@@ -47,13 +47,13 @@
         @"*.apache.org",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist schemeIsAllowed:@"http"]);
-    XCTAssertTrue([whitelist schemeIsAllowed:@"https"]);
-    XCTAssertTrue([whitelist schemeIsAllowed:@"ftp"]);
-    XCTAssertTrue([whitelist schemeIsAllowed:@"ftps"]);
-    XCTAssertFalse([whitelist schemeIsAllowed:@"gopher"]);
+    XCTAssertTrue([allowList schemeIsAllowed:@"http"]);
+    XCTAssertTrue([allowList schemeIsAllowed:@"https"]);
+    XCTAssertTrue([allowList schemeIsAllowed:@"ftp"]);
+    XCTAssertTrue([allowList schemeIsAllowed:@"ftps"]);
+    XCTAssertFalse([allowList schemeIsAllowed:@"gopher"]);
 }
 
 - (void)testSubdomainWildcard
@@ -62,12 +62,12 @@
         @"*.apache.org",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://build.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://sub1.sub0.build.apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org.ca"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://build.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://sub1.sub0.build.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org.ca"]]);
 }
 
 - (void)testCatchallWildcardOnly
@@ -76,13 +76,13 @@
         @"*",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://build.apache.prg"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"ftp://MyDangerousSite.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"ftps://apache.org.SuspiciousSite.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"gopher://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://build.apache.prg"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"ftp://MyDangerousSite.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"ftps://apache.org.SuspiciousSite.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"gopher://apache.org"]]);
 }
 
 - (void)testURISchemesNotFollowedByDoubleSlashes
@@ -92,10 +92,10 @@
                              @"sms:*",
                              nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"tel:1234567890"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"sms:1234567890"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"tel:1234567890"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"sms:1234567890"]]);
 }
 
 - (void)testCatchallWildcardByProto
@@ -107,13 +107,13 @@
         @"ftps://*",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://build.apache.prg"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"ftp://MyDangerousSite.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"ftps://apache.org.SuspiciousSite.com"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"gopher://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://build.apache.prg"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"ftp://MyDangerousSite.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"ftps://apache.org.SuspiciousSite.com"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"gopher://apache.org"]]);
 }
 
 - (void)testExactMatch
@@ -122,11 +122,11 @@
         @"www.apache.org",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://www.apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://build.apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://www.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://build.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
 }
 
 - (void)testNoMatchInQueryParam
@@ -135,10 +135,10 @@
         @"www.apache.org",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"www.malicious-site.org?url=http://www.apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"www.malicious-site.org?url=www.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"www.malicious-site.org?url=http://www.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"www.malicious-site.org?url=www.apache.org"]]);
 }
 
 - (void)testIpExactMatch
@@ -148,12 +148,12 @@
         @"192.168.2.1",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.1"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.1"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.3.1"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.1"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.1"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.3.1"]]);
 }
 
 - (void)testIpWildcardMatch
@@ -163,17 +163,17 @@
         @"192.168.2.*",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
 
-    // Ever since Cordova 3.1, whitelist wildcards are simplified, only "*" and "*.apache.org" (subdomain example) are allowed. Therefore the next four tests should fail
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.1"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.2"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.1"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.2"]]);
+    // Ever since Cordova 3.1, allowList wildcards are simplified, only "*" and "*.apache.org" (subdomain example) are allowed. Therefore the next four tests should fail
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.1"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.1.2"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.1"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.2.2"]]);
 
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://192.168.3.1"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://192.168.3.1"]]);
 }
 
 - (void)testHostnameExtraction
@@ -186,27 +186,27 @@
         @"http://apache.*/foo/bar?x=y",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org/"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://google.com/"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org/"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://google.com/"]]);
 }
 
-- (void)testWhitelistRejectionString
+- (void)testAllowListRejectionString
 {
     NSArray* allowedHosts = [NSArray arrayWithObject:@"http://www.yahoo.com/"];  // Doesn't matter in this test.
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
     NSURL* testUrl = [NSURL URLWithString:@"http://www/google.com"];
-    NSString* errorString = [whitelist errorStringForURL:testUrl];
-    NSString* expectedErrorString = [NSString stringWithFormat:kCDVDefaultWhitelistRejectionString, [testUrl absoluteString]];
+    NSString* errorString = [allowList errorStringForURL:testUrl];
+    NSString* expectedErrorString = [NSString stringWithFormat:kCDVDefaultAllowListRejectionString, [testUrl absoluteString]];
 
     XCTAssertTrue([expectedErrorString isEqualToString:errorString], @"Default error string has an unexpected value.");
 
-    whitelist.whitelistRejectionFormatString = @"Hey, '%@' is, like, bogus man!";
-    errorString = [whitelist errorStringForURL:testUrl];
-    expectedErrorString = [NSString stringWithFormat:whitelist.whitelistRejectionFormatString, [testUrl absoluteString]];
-    XCTAssertTrue([expectedErrorString isEqualToString:errorString], @"Customized whitelist rejection string has unexpected value.");
+    allowList.allowListRejectionFormatString = @"Hey, '%@' is, like, bogus man!";
+    errorString = [allowList errorStringForURL:testUrl];
+    expectedErrorString = [NSString stringWithFormat:allowList.allowListRejectionFormatString, [testUrl absoluteString]];
+    XCTAssertTrue([expectedErrorString isEqualToString:errorString], @"Customized allowList rejection string has unexpected value.");
 }
 
 - (void)testSpecificProtocol
@@ -216,12 +216,12 @@
         @"cordova://www.google.com",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://www.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"cordova://www.google.com"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"cordova://www.apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://www.google.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://www.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"cordova://www.google.com"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"cordova://www.apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://www.google.com"]]);
 }
 
 - (void)testWildcardPlusOtherUrls
@@ -233,13 +233,13 @@
         @"cordova.apache.org",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://*.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://www.google.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"ftp://cordova.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://cordova.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://cordova.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://*.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://www.google.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"ftp://cordova.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://cordova.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://cordova.apache.org"]]);
 }
 
 - (void)testWildcardScheme
@@ -248,24 +248,24 @@
         @"*://*.test.com",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"gopher://testtt.com"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"http://apache.org"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"gopher://testtt.com"]]);
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"gopher://test.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://test.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://my.test.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://test.com"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://my.test.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"gopher://test.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://test.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://my.test.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://test.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://my.test.com"]]);
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://test.com/my/path"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://my.test.com/my/path"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://test.com/my/path"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"https://my.test.com/my/path"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://test.com/my/path"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://my.test.com/my/path"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://test.com/my/path"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"https://my.test.com/my/path"]]);
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"gopher://test.com#foo"]]);
-    XCTAssertFalse([whitelist URLIsAllowed:[NSURL URLWithString:@"#foo"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"gopher://test.com#foo"]]);
+    XCTAssertFalse([allowList URLIsAllowed:[NSURL URLWithString:@"#foo"]]);
 }
 
 - (void)testCredentials
@@ -275,10 +275,10 @@
         @"http://www.google.com",
         nil];
 
-    CDVWhitelist* whitelist = [[CDVWhitelist alloc] initWithArray:allowedHosts];
+    CDVAllowList* allowList = [[CDVAllowList alloc] initWithArray:allowedHosts];
 
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://user:pass@www.apache.org"]]);
-    XCTAssertTrue([whitelist URLIsAllowed:[NSURL URLWithString:@"http://user:pass@www.google.com"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://user:pass@www.apache.org"]]);
+    XCTAssertTrue([allowList URLIsAllowed:[NSURL URLWithString:@"http://user:pass@www.google.com"]]);
 }
 
 - (void)testAllowIntentsAndNavigations
@@ -286,15 +286,15 @@
     NSArray* allowIntents = @[ @"https://*" ];
     NSArray* allowNavigations = @[ @"https://*.apache.org" ];
 
-    CDVWhitelist* intentsWhitelist = [[CDVWhitelist alloc] initWithArray:allowIntents];
-    CDVWhitelist* navigationsWhitelist = [[CDVWhitelist alloc] initWithArray:allowNavigations];
+    CDVAllowList* allowIntentsList = [[CDVAllowList alloc] initWithArray:allowIntents];
+    CDVAllowList* navigationsAllowList = [[CDVAllowList alloc] initWithArray:allowNavigations];
 
     // Test allow-navigation superceding allow-intent
-    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"https://apache.org/foo.html"] intentsWhitelist:intentsWhitelist navigationsWhitelist:navigationsWhitelist], CDVIntentAndNavigationFilterValueNavigationAllowed);
+    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"https://apache.org/foo.html"] allowIntentsList:allowIntentsList navigationsAllowList:navigationsAllowList], CDVIntentAndNavigationFilterValueNavigationAllowed);
     // Test wildcard https as allow-intent
-    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"https://google.com"] intentsWhitelist:intentsWhitelist navigationsWhitelist:navigationsWhitelist], CDVIntentAndNavigationFilterValueIntentAllowed);
+    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"https://google.com"] allowIntentsList:allowIntentsList navigationsAllowList:navigationsAllowList], CDVIntentAndNavigationFilterValueIntentAllowed);
     // Test http (not allowed in either)
-    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"http://google.com"] intentsWhitelist:intentsWhitelist navigationsWhitelist:navigationsWhitelist], CDVIntentAndNavigationFilterValueNoneAllowed);
+    XCTAssertEqual([CDVIntentAndNavigationFilter filterUrl:[NSURL URLWithString:@"http://google.com"] allowIntentsList:allowIntentsList navigationsAllowList:navigationsAllowList], CDVIntentAndNavigationFilterValueNoneAllowed);
 
     NSURL* telUrl = [NSURL URLWithString:@"tel:5555555"];
     NSMutableURLRequest* telRequest = [NSMutableURLRequest requestWithURL:telUrl];
diff --git a/tests/CordovaLibTests/CDVWebViewDelegateTests.m b/tests/CordovaLibTests/CDVWebViewDelegateTests.m
index d55ab18..72d1e9a 100644
--- a/tests/CordovaLibTests/CDVWebViewDelegateTests.m
+++ b/tests/CordovaLibTests/CDVWebViewDelegateTests.m
@@ -77,7 +77,7 @@
 
     XCTAssertTrue([wvd shouldLoadRequest:mailtoUrl], @"mailto urls should be allowed");
     XCTAssertTrue([wvd shouldLoadRequest:telUrl], @"tel urls should be allowed");
-    // as long as this is in the whitelist it should pass
+    // as long as this is in the allowList it should pass
     XCTAssertTrue([wvd shouldLoadRequest:plainUrl], @"http urls should be allowed");
 
     XCTAssertTrue([wvd shouldLoadRequest:dataUrl], @"data urls should be allowed");
diff --git a/tests/CordovaLibTests/CordovaLibTests.xcodeproj/project.pbxproj b/tests/CordovaLibTests/CordovaLibTests.xcodeproj/project.pbxproj
index f29b3cf..b367a92 100644
--- a/tests/CordovaLibTests/CordovaLibTests.xcodeproj/project.pbxproj
+++ b/tests/CordovaLibTests/CordovaLibTests.xcodeproj/project.pbxproj
@@ -8,7 +8,7 @@
 
 /* Begin PBXBuildFile section */
 		3006BCEA1D1A859B0035385C /* libCordova.a in Frameworks */ = {isa = PBXBuildFile; fileRef = 3006BCE91D1A859B0035385C /* libCordova.a */; };
-		3035621714104C34006C2D43 /* CDVWhitelistTests.m in Sources */ = {isa = PBXBuildFile; fileRef = 30356213141049E1006C2D43 /* CDVWhitelistTests.m */; };
+		3035621714104C34006C2D43 /* CDVAllowListTests.m in Sources */ = {isa = PBXBuildFile; fileRef = 30356213141049E1006C2D43 /* CDVAllowListTests.m */; };
 		303A4072152124BB00182201 /* InfoPlist.strings in Resources */ = {isa = PBXBuildFile; fileRef = 303A4070152124BB00182201 /* InfoPlist.strings */; };
 		303A4074152124BB00182201 /* main.m in Sources */ = {isa = PBXBuildFile; fileRef = 303A4073152124BB00182201 /* main.m */; };
 		303A4078152124BB00182201 /* AppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 303A4077152124BB00182201 /* AppDelegate.m */; };
@@ -30,7 +30,7 @@
 		C0FA7CA31E4BB6420077B045 /* InfoPlist.strings in Resources */ = {isa = PBXBuildFile; fileRef = 303A4070152124BB00182201 /* InfoPlist.strings */; };
 		C0FA7CA41E4BB6420077B045 /* www in Resources */ = {isa = PBXBuildFile; fileRef = 30F8AE1C152129DA006625B3 /* www */; };
 		C0FA7CA51E4BB6420077B045 /* config-custom.xml in Resources */ = {isa = PBXBuildFile; fileRef = 5C4C91771C2ACF130055AFC3 /* config-custom.xml */; };
-		C0FA7CB51E4BBBBE0077B045 /* CDVWhitelistTests.m in Sources */ = {isa = PBXBuildFile; fileRef = 30356213141049E1006C2D43 /* CDVWhitelistTests.m */; };
+		C0FA7CB51E4BBBBE0077B045 /* CDVAllowListTests.m in Sources */ = {isa = PBXBuildFile; fileRef = 30356213141049E1006C2D43 /* CDVAllowListTests.m */; };
 		C0FA7CB61E4BBBBE0077B045 /* CDVPluginResultJSONSerializationTests.m in Sources */ = {isa = PBXBuildFile; fileRef = 686357B9141002F200DF4CF2 /* CDVPluginResultJSONSerializationTests.m */; };
 		C0FA7CB91E4BBBBE0077B045 /* CDVBase64Tests.m in Sources */ = {isa = PBXBuildFile; fileRef = 30D1B08B15A2B36D0060C291 /* CDVBase64Tests.m */; };
 		C0FA7CBA1E4BBBBE0077B045 /* CDVFakeFileManager.m in Sources */ = {isa = PBXBuildFile; fileRef = EBA3554515A731F100F4DE24 /* CDVFakeFileManager.m */; };
@@ -79,7 +79,7 @@
 
 /* Begin PBXFileReference section */
 		3006BCE91D1A859B0035385C /* libCordova.a */ = {isa = PBXFileReference; lastKnownFileType = archive.ar; name = libCordova.a; path = "../Debug-iphonesimulator/libCordova.a"; sourceTree = BUILT_PRODUCTS_DIR; };
-		30356213141049E1006C2D43 /* CDVWhitelistTests.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVWhitelistTests.m; sourceTree = "<group>"; };
+		30356213141049E1006C2D43 /* CDVAllowListTests.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVAllowListTests.m; sourceTree = "<group>"; };
 		303A4068152124BB00182201 /* CordovaLibApp.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = CordovaLibApp.app; sourceTree = BUILT_PRODUCTS_DIR; };
 		303A406F152124BB00182201 /* CordovaLibApp-Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.plist; path = "CordovaLibApp-Info.plist"; sourceTree = "<group>"; };
 		303A4071152124BB00182201 /* en */ = {isa = PBXFileReference; lastKnownFileType = text.plist.strings; name = en; path = en.lproj/InfoPlist.strings; sourceTree = "<group>"; };
@@ -222,7 +222,7 @@
 				EB89634915FE66EA00E12277 /* CDVInvokedUrlCommandTests.m */,
 				686357B9141002F200DF4CF2 /* CDVPluginResultJSONSerializationTests.m */,
 				5C4C91751C2ACE450055AFC3 /* CDVViewControllerTest.m */,
-				30356213141049E1006C2D43 /* CDVWhitelistTests.m */,
+				30356213141049E1006C2D43 /* CDVAllowListTests.m */,
 				686357B1141002F200DF4CF2 /* Supporting Files */,
 			);
 			name = CordovaLibTests;
@@ -434,7 +434,7 @@
 			isa = PBXSourcesBuildPhase;
 			buildActionMask = 2147483647;
 			files = (
-				3035621714104C34006C2D43 /* CDVWhitelistTests.m in Sources */,
+				3035621714104C34006C2D43 /* CDVAllowListTests.m in Sources */,
 				686357BA141002F200DF4CF2 /* CDVPluginResultJSONSerializationTests.m in Sources */,
 				30D1B08C15A2B36D0060C291 /* CDVBase64Tests.m in Sources */,
 				EBA3554615A731F100F4DE24 /* CDVFakeFileManager.m in Sources */,
@@ -459,7 +459,7 @@
 			isa = PBXSourcesBuildPhase;
 			buildActionMask = 2147483647;
 			files = (
-				C0FA7CB51E4BBBBE0077B045 /* CDVWhitelistTests.m in Sources */,
+				C0FA7CB51E4BBBBE0077B045 /* CDVAllowListTests.m in Sources */,
 				C0FA7CB61E4BBBBE0077B045 /* CDVPluginResultJSONSerializationTests.m in Sources */,
 				C0FA7CB91E4BBBBE0077B045 /* CDVBase64Tests.m in Sources */,
 				C0FA7CBA1E4BBBBE0077B045 /* CDVFakeFileManager.m in Sources */,
diff --git a/tests/spec/unit/fixtures/dummyProj/config.xml b/tests/spec/unit/fixtures/dummyProj/config.xml
index 0841237..b9936dd 100644
--- a/tests/spec/unit/fixtures/dummyProj/config.xml
+++ b/tests/spec/unit/fixtures/dummyProj/config.xml
@@ -8,7 +8,6 @@
         Apache Cordova Team
     </author>
     <content src="index.html" />
-    <plugin name="cordova-plugin-whitelist" spec="1" />
     <access origin="*" />
     <allow-intent href="http://*/*" />
     <allow-intent href="https://*/*" />
diff --git a/tests/spec/unit/fixtures/ios-config-xml/CordovaLib/CordovaLib.xcodeproj/project.pbxproj b/tests/spec/unit/fixtures/ios-config-xml/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
index 9f39c00..6ebe647 100644
--- a/tests/spec/unit/fixtures/ios-config-xml/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
+++ b/tests/spec/unit/fixtures/ios-config-xml/CordovaLib/CordovaLib.xcodeproj/project.pbxproj
@@ -56,8 +56,8 @@
 		7ED95D501AB9029B008C4574 /* CDVViewController.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2A1AB9029B008C4574 /* CDVViewController.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		7ED95D511AB9029B008C4574 /* CDVViewController.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2B1AB9029B008C4574 /* CDVViewController.m */; };
 		7ED95D521AB9029B008C4574 /* CDVWebViewEngineProtocol.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		7ED95D531AB9029B008C4574 /* CDVWhitelist.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		7ED95D541AB9029B008C4574 /* CDVWhitelist.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */; };
+		7ED95D531AB9029B008C4574 /* CDVAllowList.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		7ED95D541AB9029B008C4574 /* CDVAllowList.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */; };
 		7ED95D571AB9029B008C4574 /* NSDictionary+CordovaPreferences.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		7ED95D581AB9029B008C4574 /* NSDictionary+CordovaPreferences.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */; };
 		7ED95D591AB9029B008C4574 /* NSMutableArray+QueueAdditions.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */; settings = {ATTRIBUTES = (Public, ); }; };
@@ -74,7 +74,7 @@
 		9052DE7A2150D040008E83D4 /* CDVURLProtocol.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D271AB9029B008C4574 /* CDVURLProtocol.m */; };
 		9052DE7B2150D040008E83D4 /* CDVUserAgentUtil.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D291AB9029B008C4574 /* CDVUserAgentUtil.m */; };
 		9052DE7C2150D040008E83D4 /* CDVViewController.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2B1AB9029B008C4574 /* CDVViewController.m */; };
-		9052DE7D2150D040008E83D4 /* CDVWhitelist.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */; };
+		9052DE7D2150D040008E83D4 /* CDVAllowList.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */; };
 		9052DE7E2150D040008E83D4 /* NSDictionary+CordovaPreferences.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */; };
 		9052DE7F2150D040008E83D4 /* NSMutableArray+QueueAdditions.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95D341AB9029B008C4574 /* NSMutableArray+QueueAdditions.m */; };
 		9052DE802150D040008E83D4 /* CDVJSON_private.m in Sources */ = {isa = PBXBuildFile; fileRef = 7ED95CF41AB9028C008C4574 /* CDVJSON_private.m */; };
@@ -112,7 +112,7 @@
 		C0C01ECA1E39131A0056E6CB /* CDVUserAgentUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D281AB9029B008C4574 /* CDVUserAgentUtil.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECB1E39131A0056E6CB /* CDVViewController.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2A1AB9029B008C4574 /* CDVViewController.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECC1E39131A0056E6CB /* CDVWebViewEngineProtocol.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		C0C01ECD1E39131A0056E6CB /* CDVWhitelist.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */; settings = {ATTRIBUTES = (Public, ); }; };
+		C0C01ECD1E39131A0056E6CB /* CDVAllowList.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECE1E39131A0056E6CB /* NSDictionary+CordovaPreferences.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		C0C01ECF1E39131A0056E6CB /* NSMutableArray+QueueAdditions.h in Headers */ = {isa = PBXBuildFile; fileRef = 7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */; settings = {ATTRIBUTES = (Public, ); }; };
 /* End PBXBuildFile section */
@@ -167,8 +167,8 @@
 		7ED95D2A1AB9029B008C4574 /* CDVViewController.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVViewController.h; sourceTree = "<group>"; };
 		7ED95D2B1AB9029B008C4574 /* CDVViewController.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVViewController.m; sourceTree = "<group>"; };
 		7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVWebViewEngineProtocol.h; sourceTree = "<group>"; };
-		7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVWhitelist.h; sourceTree = "<group>"; };
-		7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVWhitelist.m; sourceTree = "<group>"; };
+		7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = CDVAllowList.h; sourceTree = "<group>"; };
+		7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = CDVAllowList.m; sourceTree = "<group>"; };
 		7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = "NSDictionary+CordovaPreferences.h"; sourceTree = "<group>"; };
 		7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = "NSDictionary+CordovaPreferences.m"; sourceTree = "<group>"; };
 		7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = "NSMutableArray+QueueAdditions.h"; sourceTree = "<group>"; };
@@ -327,8 +327,8 @@
 				7ED95D2A1AB9029B008C4574 /* CDVViewController.h */,
 				7ED95D2B1AB9029B008C4574 /* CDVViewController.m */,
 				7ED95D2C1AB9029B008C4574 /* CDVWebViewEngineProtocol.h */,
-				7ED95D2D1AB9029B008C4574 /* CDVWhitelist.h */,
-				7ED95D2E1AB9029B008C4574 /* CDVWhitelist.m */,
+				7ED95D2D1AB9029B008C4574 /* CDVAllowList.h */,
+				7ED95D2E1AB9029B008C4574 /* CDVAllowList.m */,
 				7ED95D311AB9029B008C4574 /* NSDictionary+CordovaPreferences.h */,
 				7ED95D321AB9029B008C4574 /* NSDictionary+CordovaPreferences.m */,
 				7ED95D331AB9029B008C4574 /* NSMutableArray+QueueAdditions.h */,
@@ -382,7 +382,7 @@
 				C0C01ECA1E39131A0056E6CB /* CDVUserAgentUtil.h in Headers */,
 				C0C01ECB1E39131A0056E6CB /* CDVViewController.h in Headers */,
 				C0C01ECC1E39131A0056E6CB /* CDVWebViewEngineProtocol.h in Headers */,
-				C0C01ECD1E39131A0056E6CB /* CDVWhitelist.h in Headers */,
+				C0C01ECD1E39131A0056E6CB /* CDVAllowList.h in Headers */,
 				C0C01ECE1E39131A0056E6CB /* NSDictionary+CordovaPreferences.h in Headers */,
 				4E23F90323E17FFA006CD852 /* CDVWebViewUIDelegate.h in Headers */,
 				C0C01ECF1E39131A0056E6CB /* NSMutableArray+QueueAdditions.h in Headers */,
@@ -422,7 +422,7 @@
 				7ED95D501AB9029B008C4574 /* CDVViewController.h in Headers */,
 				7ED95D521AB9029B008C4574 /* CDVWebViewEngineProtocol.h in Headers */,
 				4E23F90023E16E96006CD852 /* CDVWebViewEngine.h in Headers */,
-				7ED95D531AB9029B008C4574 /* CDVWhitelist.h in Headers */,
+				7ED95D531AB9029B008C4574 /* CDVAllowList.h in Headers */,
 				7ED95D571AB9029B008C4574 /* NSDictionary+CordovaPreferences.h in Headers */,
 				7ED95D591AB9029B008C4574 /* NSMutableArray+QueueAdditions.h in Headers */,
 				7ED95D021AB9028C008C4574 /* CDVDebug.h in Headers */,
@@ -526,7 +526,7 @@
 				9052DE7A2150D040008E83D4 /* CDVURLProtocol.m in Sources */,
 				9052DE7B2150D040008E83D4 /* CDVUserAgentUtil.m in Sources */,
 				9052DE7C2150D040008E83D4 /* CDVViewController.m in Sources */,
-				9052DE7D2150D040008E83D4 /* CDVWhitelist.m in Sources */,
+				9052DE7D2150D040008E83D4 /* CDVAllowList.m in Sources */,
 				9052DE7E2150D040008E83D4 /* NSDictionary+CordovaPreferences.m in Sources */,
 				9052DE7F2150D040008E83D4 /* NSMutableArray+QueueAdditions.m in Sources */,
 				9052DE802150D040008E83D4 /* CDVJSON_private.m in Sources */,
@@ -556,7 +556,7 @@
 				4E23F8FB23E16E96006CD852 /* CDVWebViewProcessPoolFactory.m in Sources */,
 				7ED95D4F1AB9029B008C4574 /* CDVUserAgentUtil.m in Sources */,
 				7ED95D511AB9029B008C4574 /* CDVViewController.m in Sources */,
-				7ED95D541AB9029B008C4574 /* CDVWhitelist.m in Sources */,
+				7ED95D541AB9029B008C4574 /* CDVAllowList.m in Sources */,
 				7ED95D581AB9029B008C4574 /* NSDictionary+CordovaPreferences.m in Sources */,
 				7ED95D5A1AB9029B008C4574 /* NSMutableArray+QueueAdditions.m in Sources */,
 				7ED95D041AB9028C008C4574 /* CDVJSON_private.m in Sources */,

---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@cordova.apache.org
For additional commands, e-mail: commits-help@cordova.apache.org
diff --git a/CordovaLib/Classes/Public/CDVWhitelist.m b/CordovaLib/Classes/Public/CDVAllowList.m
similarity index 86%
rename from CordovaLib/Classes/Public/CDVWhitelist.m
rename to CordovaLib/Classes/Public/CDVAllowList.m
index 758f4d1..a0ce668 100644
--- a/CordovaLib/Classes/Public/CDVWhitelist.m
+++ b/CordovaLib/Classes/Public/CDVAllowList.m
@@ -17,12 +17,12 @@
  under the License.
  */
 
-#import "CDVWhitelist.h"
+#import "CDVAllowList.h"
 
-NSString* const kCDVDefaultWhitelistRejectionString = @"ERROR whitelist rejection: url='%@'";
+NSString* const kCDVDefaultAllowListRejectionString = @"ERROR allowList rejection: url='%@'";
 NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
-@interface CDVWhitelistPattern : NSObject {
+@interface CDVAllowListPattern : NSObject {
     @private
     NSRegularExpression* _scheme;
     NSRegularExpression* _host;
@@ -36,7 +36,7 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
 @end
 
-@implementation CDVWhitelistPattern
+@implementation CDVAllowListPattern
 
 + (NSString*)regexFromPattern:(NSString*)pattern allowWildcards:(bool)allowWildcards
 {
@@ -62,14 +62,14 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
         if ((scheme == nil) || [scheme isEqualToString:@"*"]) {
             _scheme = nil;
         } else {
-            _scheme = [NSRegularExpression regularExpressionWithPattern:[CDVWhitelistPattern regexFromPattern:scheme allowWildcards:NO] options:NSRegularExpressionCaseInsensitive error:nil];
+            _scheme = [NSRegularExpression regularExpressionWithPattern:[CDVAllowListPattern regexFromPattern:scheme allowWildcards:NO] options:NSRegularExpressionCaseInsensitive error:nil];
         }
         if ([host isEqualToString:@"*"] || host == nil) {
             _host = nil;
         } else if ([host hasPrefix:@"*."]) {
-            _host = [NSRegularExpression regularExpressionWithPattern:[NSString stringWithFormat:@"([a-z0-9.-]*\\.)?%@", [CDVWhitelistPattern regexFromPattern:[host substringFromIndex:2] allowWildcards:false]] options:NSRegularExpressionCaseInsensitive error:nil];
+            _host = [NSRegularExpression regularExpressionWithPattern:[NSString stringWithFormat:@"([a-z0-9.-]*\\.)?%@", [CDVAllowListPattern regexFromPattern:[host substringFromIndex:2] allowWildcards:false]] options:NSRegularExpressionCaseInsensitive error:nil];
         } else {
-            _host = [NSRegularExpression regularExpressionWithPattern:[CDVWhitelistPattern regexFromPattern:host allowWildcards:NO] options:NSRegularExpressionCaseInsensitive error:nil];
+            _host = [NSRegularExpression regularExpressionWithPattern:[CDVAllowListPattern regexFromPattern:host allowWildcards:NO] options:NSRegularExpressionCaseInsensitive error:nil];
         }
         if ((port == nil) || [port isEqualToString:@"*"]) {
             _port = nil;
@@ -79,7 +79,7 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
         if ((path == nil) || [path isEqualToString:@"/*"]) {
             _path = nil;
         } else {
-            _path = [NSRegularExpression regularExpressionWithPattern:[CDVWhitelistPattern regexFromPattern:path allowWildcards:YES] options:0 error:nil];
+            _path = [NSRegularExpression regularExpressionWithPattern:[CDVAllowListPattern regexFromPattern:path allowWildcards:YES] options:0 error:nil];
         }
     }
     return self;
@@ -96,29 +96,29 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
 @end
 
-@interface CDVWhitelist ()
+@interface CDVAllowList ()
 
-@property (nonatomic, readwrite, strong) NSMutableArray* whitelist;
+@property (nonatomic, readwrite, strong) NSMutableArray* allowList;
 @property (nonatomic, readwrite, strong) NSMutableSet* permittedSchemes;
 
-- (void)addWhiteListEntry:(NSString*)pattern;
+- (void)addAllowListEntry:(NSString*)pattern;
 
 @end
 
-@implementation CDVWhitelist
+@implementation CDVAllowList
 
-@synthesize whitelist, permittedSchemes, whitelistRejectionFormatString;
+@synthesize allowList, permittedSchemes, allowListRejectionFormatString;
 
 - (id)initWithArray:(NSArray*)array
 {
     self = [super init];
     if (self) {
-        self.whitelist = [[NSMutableArray alloc] init];
+        self.allowList = [[NSMutableArray alloc] init];
         self.permittedSchemes = [[NSMutableSet alloc] init];
-        self.whitelistRejectionFormatString = kCDVDefaultWhitelistRejectionString;
+        self.allowListRejectionFormatString = kCDVDefaultAllowListRejectionString;
 
         for (NSString* pattern in array) {
-            [self addWhiteListEntry:pattern];
+            [self addAllowListEntry:pattern];
         }
     }
     return self;
@@ -158,15 +158,15 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
     return YES;
 }
 
-- (void)addWhiteListEntry:(NSString*)origin
+- (void)addAllowListEntry:(NSString*)origin
 {
-    if (self.whitelist == nil) {
+    if (self.allowList == nil) {
         return;
     }
 
     if ([origin isEqualToString:@"*"]) {
         NSLog(@"Unlimited access to network resources");
-        self.whitelist = nil;
+        self.allowList = nil;
         self.permittedSchemes = nil;
     } else { // specific access
         NSRegularExpression* parts = [NSRegularExpression regularExpressionWithPattern:@"^((\\*|[A-Za-z-]+):/?/?)?(((\\*\\.)?[^*/:]+)|\\*)?(:(\\d+))?(/.*)?" options:0 error:nil];
@@ -204,10 +204,10 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
             if (scheme == nil) {
                 // XXX making it stupid friendly for people who forget to include protocol/SSL
-                [self.whitelist addObject:[[CDVWhitelistPattern alloc] initWithScheme:@"http" host:host port:port path:path]];
-                [self.whitelist addObject:[[CDVWhitelistPattern alloc] initWithScheme:@"https" host:host port:port path:path]];
+                [self.allowList addObject:[[CDVAllowListPattern alloc] initWithScheme:@"http" host:host port:port path:path]];
+                [self.allowList addObject:[[CDVAllowListPattern alloc] initWithScheme:@"https" host:host port:port path:path]];
             } else {
-                [self.whitelist addObject:[[CDVWhitelistPattern alloc] initWithScheme:scheme host:host port:port path:path]];
+                [self.allowList addObject:[[CDVAllowListPattern alloc] initWithScheme:scheme host:host port:port path:path]];
             }
 
             if (self.permittedSchemes != nil) {
@@ -240,8 +240,8 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
 - (BOOL)URLIsAllowed:(NSURL*)url logFailure:(BOOL)logFailure
 {
-    // Shortcut acceptance: Are all urls whitelisted ("*" in whitelist)?
-    if (whitelist == nil) {
+    // Shortcut acceptance: Are all urls allowListed ("*" in allowList)?
+    if (allowList == nil) {
         return YES;
     }
 
@@ -263,8 +263,8 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
         }
     }
 
-    // Check the url against patterns in the whitelist
-    for (CDVWhitelistPattern* p in self.whitelist) {
+    // Check the url against patterns in the allowList
+    for (CDVAllowListPattern* p in self.allowList) {
         if ([p matches:url]) {
             return YES;
         }
@@ -279,7 +279,7 @@ NSString* const kCDVDefaultSchemeName = @"cdv-default-scheme";
 
 - (NSString*)errorStringForURL:(NSURL*)url
 {
-    return [NSString stringWithFormat:self.whitelistRejectionFormatString, [url absoluteString]];
+    return [NSString stringWithFormat:self.allowListRejectionFormatString, [url absoluteString]];
 }
 
 @end